# laygo2

[![PyPI version](https://badge.fury.io/py/laygo2.svg)](https://badge.fury.io/py/laygo2)

(The commit history is cleaned up on 6-27-2022)

The LAYout with Gridded Object 2 (LAYGO2) is a layout generation framework
for custom integrated circuits. [\[Source code\]](https://github.com/niftylab/laygo2) [\[Documentation\]](https://laygo2.github.io/)


LAYGO2 provides a rich and productive layout design environment for designers
with several advanced concepts such templates and grids.

For further documentation, see [https://laygo2.github.io/](https://laygo2.github.io/).

Contributors: 
Jaeduk Han, Taeho Shin, Dongjun Lee, Dongwhee Kim, Gaeryun Sung, Wookjin Shin, Yunseong Jo, Hyungjoo Park, Seonghyun Park, Youngmin Oh, Taeseung Kang
